# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class InstanceForDescribeInstancesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_options': 'CpuOptionsForDescribeInstancesOutput',
        'cpus': 'int',
        'created_at': 'str',
        'deployment_set_id': 'str',
        'description': 'str',
        'eip_address': 'EipAddressForDescribeInstancesOutput',
        'expired_at': 'str',
        'host_name': 'str',
        'hostname': 'str',
        'image_id': 'str',
        'instance_charge_type': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_type_id': 'str',
        'key_pair_id': 'str',
        'key_pair_name': 'str',
        'local_volumes': 'list[LocalVolumeForDescribeInstancesOutput]',
        'memory_size': 'int',
        'network_interfaces': 'list[NetworkInterfaceForDescribeInstancesOutput]',
        'os_name': 'str',
        'os_type': 'str',
        'project_name': 'str',
        'rdma_ip_addresses': 'list[str]',
        'spot_strategy': 'str',
        'status': 'str',
        'stopped_mode': 'str',
        'tags': 'list[TagForDescribeInstancesOutput]',
        'updated_at': 'str',
        'uuid': 'str',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'cpu_options': 'CpuOptions',
        'cpus': 'Cpus',
        'created_at': 'CreatedAt',
        'deployment_set_id': 'DeploymentSetId',
        'description': 'Description',
        'eip_address': 'EipAddress',
        'expired_at': 'ExpiredAt',
        'host_name': 'HostName',
        'hostname': 'Hostname',
        'image_id': 'ImageId',
        'instance_charge_type': 'InstanceChargeType',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_type_id': 'InstanceTypeId',
        'key_pair_id': 'KeyPairId',
        'key_pair_name': 'KeyPairName',
        'local_volumes': 'LocalVolumes',
        'memory_size': 'MemorySize',
        'network_interfaces': 'NetworkInterfaces',
        'os_name': 'OsName',
        'os_type': 'OsType',
        'project_name': 'ProjectName',
        'rdma_ip_addresses': 'RdmaIpAddresses',
        'spot_strategy': 'SpotStrategy',
        'status': 'Status',
        'stopped_mode': 'StoppedMode',
        'tags': 'Tags',
        'updated_at': 'UpdatedAt',
        'uuid': 'Uuid',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, cpu_options=None, cpus=None, created_at=None, deployment_set_id=None, description=None, eip_address=None, expired_at=None, host_name=None, hostname=None, image_id=None, instance_charge_type=None, instance_id=None, instance_name=None, instance_type_id=None, key_pair_id=None, key_pair_name=None, local_volumes=None, memory_size=None, network_interfaces=None, os_name=None, os_type=None, project_name=None, rdma_ip_addresses=None, spot_strategy=None, status=None, stopped_mode=None, tags=None, updated_at=None, uuid=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """InstanceForDescribeInstancesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_options = None
        self._cpus = None
        self._created_at = None
        self._deployment_set_id = None
        self._description = None
        self._eip_address = None
        self._expired_at = None
        self._host_name = None
        self._hostname = None
        self._image_id = None
        self._instance_charge_type = None
        self._instance_id = None
        self._instance_name = None
        self._instance_type_id = None
        self._key_pair_id = None
        self._key_pair_name = None
        self._local_volumes = None
        self._memory_size = None
        self._network_interfaces = None
        self._os_name = None
        self._os_type = None
        self._project_name = None
        self._rdma_ip_addresses = None
        self._spot_strategy = None
        self._status = None
        self._stopped_mode = None
        self._tags = None
        self._updated_at = None
        self._uuid = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if cpu_options is not None:
            self.cpu_options = cpu_options
        if cpus is not None:
            self.cpus = cpus
        if created_at is not None:
            self.created_at = created_at
        if deployment_set_id is not None:
            self.deployment_set_id = deployment_set_id
        if description is not None:
            self.description = description
        if eip_address is not None:
            self.eip_address = eip_address
        if expired_at is not None:
            self.expired_at = expired_at
        if host_name is not None:
            self.host_name = host_name
        if hostname is not None:
            self.hostname = hostname
        if image_id is not None:
            self.image_id = image_id
        if instance_charge_type is not None:
            self.instance_charge_type = instance_charge_type
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_type_id is not None:
            self.instance_type_id = instance_type_id
        if key_pair_id is not None:
            self.key_pair_id = key_pair_id
        if key_pair_name is not None:
            self.key_pair_name = key_pair_name
        if local_volumes is not None:
            self.local_volumes = local_volumes
        if memory_size is not None:
            self.memory_size = memory_size
        if network_interfaces is not None:
            self.network_interfaces = network_interfaces
        if os_name is not None:
            self.os_name = os_name
        if os_type is not None:
            self.os_type = os_type
        if project_name is not None:
            self.project_name = project_name
        if rdma_ip_addresses is not None:
            self.rdma_ip_addresses = rdma_ip_addresses
        if spot_strategy is not None:
            self.spot_strategy = spot_strategy
        if status is not None:
            self.status = status
        if stopped_mode is not None:
            self.stopped_mode = stopped_mode
        if tags is not None:
            self.tags = tags
        if updated_at is not None:
            self.updated_at = updated_at
        if uuid is not None:
            self.uuid = uuid
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def cpu_options(self):
        """Gets the cpu_options of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The cpu_options of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: CpuOptionsForDescribeInstancesOutput
        """
        return self._cpu_options

    @cpu_options.setter
    def cpu_options(self, cpu_options):
        """Sets the cpu_options of this InstanceForDescribeInstancesOutput.


        :param cpu_options: The cpu_options of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: CpuOptionsForDescribeInstancesOutput
        """

        self._cpu_options = cpu_options

    @property
    def cpus(self):
        """Gets the cpus of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The cpus of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: int
        """
        return self._cpus

    @cpus.setter
    def cpus(self, cpus):
        """Sets the cpus of this InstanceForDescribeInstancesOutput.


        :param cpus: The cpus of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: int
        """

        self._cpus = cpus

    @property
    def created_at(self):
        """Gets the created_at of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The created_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InstanceForDescribeInstancesOutput.


        :param created_at: The created_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def deployment_set_id(self):
        """Gets the deployment_set_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The deployment_set_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._deployment_set_id

    @deployment_set_id.setter
    def deployment_set_id(self, deployment_set_id):
        """Sets the deployment_set_id of this InstanceForDescribeInstancesOutput.


        :param deployment_set_id: The deployment_set_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._deployment_set_id = deployment_set_id

    @property
    def description(self):
        """Gets the description of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The description of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InstanceForDescribeInstancesOutput.


        :param description: The description of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def eip_address(self):
        """Gets the eip_address of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The eip_address of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: EipAddressForDescribeInstancesOutput
        """
        return self._eip_address

    @eip_address.setter
    def eip_address(self, eip_address):
        """Sets the eip_address of this InstanceForDescribeInstancesOutput.


        :param eip_address: The eip_address of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: EipAddressForDescribeInstancesOutput
        """

        self._eip_address = eip_address

    @property
    def expired_at(self):
        """Gets the expired_at of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The expired_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_at

    @expired_at.setter
    def expired_at(self, expired_at):
        """Sets the expired_at of this InstanceForDescribeInstancesOutput.


        :param expired_at: The expired_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._expired_at = expired_at

    @property
    def host_name(self):
        """Gets the host_name of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The host_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """Sets the host_name of this InstanceForDescribeInstancesOutput.


        :param host_name: The host_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._host_name = host_name

    @property
    def hostname(self):
        """Gets the hostname of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The hostname of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this InstanceForDescribeInstancesOutput.


        :param hostname: The hostname of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def image_id(self):
        """Gets the image_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The image_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this InstanceForDescribeInstancesOutput.


        :param image_id: The image_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def instance_charge_type(self):
        """Gets the instance_charge_type of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The instance_charge_type of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_charge_type

    @instance_charge_type.setter
    def instance_charge_type(self, instance_charge_type):
        """Sets the instance_charge_type of this InstanceForDescribeInstancesOutput.


        :param instance_charge_type: The instance_charge_type of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_charge_type = instance_charge_type

    @property
    def instance_id(self):
        """Gets the instance_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The instance_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this InstanceForDescribeInstancesOutput.


        :param instance_id: The instance_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The instance_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this InstanceForDescribeInstancesOutput.


        :param instance_name: The instance_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_type_id(self):
        """Gets the instance_type_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The instance_type_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_id

    @instance_type_id.setter
    def instance_type_id(self, instance_type_id):
        """Sets the instance_type_id of this InstanceForDescribeInstancesOutput.


        :param instance_type_id: The instance_type_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_type_id = instance_type_id

    @property
    def key_pair_id(self):
        """Gets the key_pair_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The key_pair_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._key_pair_id

    @key_pair_id.setter
    def key_pair_id(self, key_pair_id):
        """Sets the key_pair_id of this InstanceForDescribeInstancesOutput.


        :param key_pair_id: The key_pair_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._key_pair_id = key_pair_id

    @property
    def key_pair_name(self):
        """Gets the key_pair_name of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The key_pair_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._key_pair_name

    @key_pair_name.setter
    def key_pair_name(self, key_pair_name):
        """Sets the key_pair_name of this InstanceForDescribeInstancesOutput.


        :param key_pair_name: The key_pair_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._key_pair_name = key_pair_name

    @property
    def local_volumes(self):
        """Gets the local_volumes of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The local_volumes of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: list[LocalVolumeForDescribeInstancesOutput]
        """
        return self._local_volumes

    @local_volumes.setter
    def local_volumes(self, local_volumes):
        """Sets the local_volumes of this InstanceForDescribeInstancesOutput.


        :param local_volumes: The local_volumes of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: list[LocalVolumeForDescribeInstancesOutput]
        """

        self._local_volumes = local_volumes

    @property
    def memory_size(self):
        """Gets the memory_size of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The memory_size of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: int
        """
        return self._memory_size

    @memory_size.setter
    def memory_size(self, memory_size):
        """Sets the memory_size of this InstanceForDescribeInstancesOutput.


        :param memory_size: The memory_size of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: int
        """

        self._memory_size = memory_size

    @property
    def network_interfaces(self):
        """Gets the network_interfaces of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The network_interfaces of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: list[NetworkInterfaceForDescribeInstancesOutput]
        """
        return self._network_interfaces

    @network_interfaces.setter
    def network_interfaces(self, network_interfaces):
        """Sets the network_interfaces of this InstanceForDescribeInstancesOutput.


        :param network_interfaces: The network_interfaces of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: list[NetworkInterfaceForDescribeInstancesOutput]
        """

        self._network_interfaces = network_interfaces

    @property
    def os_name(self):
        """Gets the os_name of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The os_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._os_name

    @os_name.setter
    def os_name(self, os_name):
        """Sets the os_name of this InstanceForDescribeInstancesOutput.


        :param os_name: The os_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._os_name = os_name

    @property
    def os_type(self):
        """Gets the os_type of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The os_type of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._os_type

    @os_type.setter
    def os_type(self, os_type):
        """Sets the os_type of this InstanceForDescribeInstancesOutput.


        :param os_type: The os_type of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._os_type = os_type

    @property
    def project_name(self):
        """Gets the project_name of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The project_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this InstanceForDescribeInstancesOutput.


        :param project_name: The project_name of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def rdma_ip_addresses(self):
        """Gets the rdma_ip_addresses of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The rdma_ip_addresses of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._rdma_ip_addresses

    @rdma_ip_addresses.setter
    def rdma_ip_addresses(self, rdma_ip_addresses):
        """Sets the rdma_ip_addresses of this InstanceForDescribeInstancesOutput.


        :param rdma_ip_addresses: The rdma_ip_addresses of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: list[str]
        """

        self._rdma_ip_addresses = rdma_ip_addresses

    @property
    def spot_strategy(self):
        """Gets the spot_strategy of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The spot_strategy of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._spot_strategy

    @spot_strategy.setter
    def spot_strategy(self, spot_strategy):
        """Sets the spot_strategy of this InstanceForDescribeInstancesOutput.


        :param spot_strategy: The spot_strategy of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._spot_strategy = spot_strategy

    @property
    def status(self):
        """Gets the status of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The status of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InstanceForDescribeInstancesOutput.


        :param status: The status of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def stopped_mode(self):
        """Gets the stopped_mode of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The stopped_mode of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._stopped_mode

    @stopped_mode.setter
    def stopped_mode(self, stopped_mode):
        """Sets the stopped_mode of this InstanceForDescribeInstancesOutput.


        :param stopped_mode: The stopped_mode of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._stopped_mode = stopped_mode

    @property
    def tags(self):
        """Gets the tags of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The tags of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: list[TagForDescribeInstancesOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this InstanceForDescribeInstancesOutput.


        :param tags: The tags of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: list[TagForDescribeInstancesOutput]
        """

        self._tags = tags

    @property
    def updated_at(self):
        """Gets the updated_at of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The updated_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this InstanceForDescribeInstancesOutput.


        :param updated_at: The updated_at of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def uuid(self):
        """Gets the uuid of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The uuid of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InstanceForDescribeInstancesOutput.


        :param uuid: The uuid of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def vpc_id(self):
        """Gets the vpc_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The vpc_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this InstanceForDescribeInstancesOutput.


        :param vpc_id: The vpc_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this InstanceForDescribeInstancesOutput.  # noqa: E501


        :return: The zone_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this InstanceForDescribeInstancesOutput.


        :param zone_id: The zone_id of this InstanceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstanceForDescribeInstancesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceForDescribeInstancesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstanceForDescribeInstancesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class InstanceTypeForDescribeInstanceTypesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'baseline_credit': 'int',
        'gpu': 'GpuForDescribeInstanceTypesOutput',
        'initial_credit': 'int',
        'instance_type_family': 'str',
        'instance_type_id': 'str',
        'local_volumes': 'list[LocalVolumeForDescribeInstanceTypesOutput]',
        'memory': 'MemoryForDescribeInstanceTypesOutput',
        'network': 'NetworkForDescribeInstanceTypesOutput',
        'processor': 'ProcessorForDescribeInstanceTypesOutput',
        'rdma': 'RdmaForDescribeInstanceTypesOutput',
        'volume': 'VolumeForDescribeInstanceTypesOutput'
    }

    attribute_map = {
        'baseline_credit': 'BaselineCredit',
        'gpu': 'Gpu',
        'initial_credit': 'InitialCredit',
        'instance_type_family': 'InstanceTypeFamily',
        'instance_type_id': 'InstanceTypeId',
        'local_volumes': 'LocalVolumes',
        'memory': 'Memory',
        'network': 'Network',
        'processor': 'Processor',
        'rdma': 'Rdma',
        'volume': 'Volume'
    }

    def __init__(self, baseline_credit=None, gpu=None, initial_credit=None, instance_type_family=None, instance_type_id=None, local_volumes=None, memory=None, network=None, processor=None, rdma=None, volume=None, _configuration=None):  # noqa: E501
        """InstanceTypeForDescribeInstanceTypesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._baseline_credit = None
        self._gpu = None
        self._initial_credit = None
        self._instance_type_family = None
        self._instance_type_id = None
        self._local_volumes = None
        self._memory = None
        self._network = None
        self._processor = None
        self._rdma = None
        self._volume = None
        self.discriminator = None

        if baseline_credit is not None:
            self.baseline_credit = baseline_credit
        if gpu is not None:
            self.gpu = gpu
        if initial_credit is not None:
            self.initial_credit = initial_credit
        if instance_type_family is not None:
            self.instance_type_family = instance_type_family
        if instance_type_id is not None:
            self.instance_type_id = instance_type_id
        if local_volumes is not None:
            self.local_volumes = local_volumes
        if memory is not None:
            self.memory = memory
        if network is not None:
            self.network = network
        if processor is not None:
            self.processor = processor
        if rdma is not None:
            self.rdma = rdma
        if volume is not None:
            self.volume = volume

    @property
    def baseline_credit(self):
        """Gets the baseline_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The baseline_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: int
        """
        return self._baseline_credit

    @baseline_credit.setter
    def baseline_credit(self, baseline_credit):
        """Sets the baseline_credit of this InstanceTypeForDescribeInstanceTypesOutput.


        :param baseline_credit: The baseline_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: int
        """

        self._baseline_credit = baseline_credit

    @property
    def gpu(self):
        """Gets the gpu of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The gpu of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: GpuForDescribeInstanceTypesOutput
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu):
        """Sets the gpu of this InstanceTypeForDescribeInstanceTypesOutput.


        :param gpu: The gpu of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: GpuForDescribeInstanceTypesOutput
        """

        self._gpu = gpu

    @property
    def initial_credit(self):
        """Gets the initial_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The initial_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: int
        """
        return self._initial_credit

    @initial_credit.setter
    def initial_credit(self, initial_credit):
        """Sets the initial_credit of this InstanceTypeForDescribeInstanceTypesOutput.


        :param initial_credit: The initial_credit of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: int
        """

        self._initial_credit = initial_credit

    @property
    def instance_type_family(self):
        """Gets the instance_type_family of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The instance_type_family of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_family

    @instance_type_family.setter
    def instance_type_family(self, instance_type_family):
        """Sets the instance_type_family of this InstanceTypeForDescribeInstanceTypesOutput.


        :param instance_type_family: The instance_type_family of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: str
        """

        self._instance_type_family = instance_type_family

    @property
    def instance_type_id(self):
        """Gets the instance_type_id of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The instance_type_id of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_id

    @instance_type_id.setter
    def instance_type_id(self, instance_type_id):
        """Sets the instance_type_id of this InstanceTypeForDescribeInstanceTypesOutput.


        :param instance_type_id: The instance_type_id of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: str
        """

        self._instance_type_id = instance_type_id

    @property
    def local_volumes(self):
        """Gets the local_volumes of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The local_volumes of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: list[LocalVolumeForDescribeInstanceTypesOutput]
        """
        return self._local_volumes

    @local_volumes.setter
    def local_volumes(self, local_volumes):
        """Sets the local_volumes of this InstanceTypeForDescribeInstanceTypesOutput.


        :param local_volumes: The local_volumes of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: list[LocalVolumeForDescribeInstanceTypesOutput]
        """

        self._local_volumes = local_volumes

    @property
    def memory(self):
        """Gets the memory of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The memory of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: MemoryForDescribeInstanceTypesOutput
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this InstanceTypeForDescribeInstanceTypesOutput.


        :param memory: The memory of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: MemoryForDescribeInstanceTypesOutput
        """

        self._memory = memory

    @property
    def network(self):
        """Gets the network of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The network of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: NetworkForDescribeInstanceTypesOutput
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this InstanceTypeForDescribeInstanceTypesOutput.


        :param network: The network of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: NetworkForDescribeInstanceTypesOutput
        """

        self._network = network

    @property
    def processor(self):
        """Gets the processor of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The processor of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: ProcessorForDescribeInstanceTypesOutput
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this InstanceTypeForDescribeInstanceTypesOutput.


        :param processor: The processor of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: ProcessorForDescribeInstanceTypesOutput
        """

        self._processor = processor

    @property
    def rdma(self):
        """Gets the rdma of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The rdma of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: RdmaForDescribeInstanceTypesOutput
        """
        return self._rdma

    @rdma.setter
    def rdma(self, rdma):
        """Sets the rdma of this InstanceTypeForDescribeInstanceTypesOutput.


        :param rdma: The rdma of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: RdmaForDescribeInstanceTypesOutput
        """

        self._rdma = rdma

    @property
    def volume(self):
        """Gets the volume of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501


        :return: The volume of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :rtype: VolumeForDescribeInstanceTypesOutput
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this InstanceTypeForDescribeInstanceTypesOutput.


        :param volume: The volume of this InstanceTypeForDescribeInstanceTypesOutput.  # noqa: E501
        :type: VolumeForDescribeInstanceTypesOutput
        """

        self._volume = volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstanceTypeForDescribeInstanceTypesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceTypeForDescribeInstanceTypesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstanceTypeForDescribeInstanceTypesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDBInstanceDetailResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'basic_info': 'BasicInfoForDescribeDBInstanceDetailOutput',
        'charge_detail': 'ChargeDetailForDescribeDBInstanceDetailOutput',
        'endpoints': 'list[EndpointForDescribeDBInstanceDetailOutput]',
        'nodes': 'list[NodeForDescribeDBInstanceDetailOutput]'
    }

    attribute_map = {
        'basic_info': 'BasicInfo',
        'charge_detail': 'ChargeDetail',
        'endpoints': 'Endpoints',
        'nodes': 'Nodes'
    }

    def __init__(self, basic_info=None, charge_detail=None, endpoints=None, nodes=None, _configuration=None):  # noqa: E501
        """DescribeDBInstanceDetailResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._basic_info = None
        self._charge_detail = None
        self._endpoints = None
        self._nodes = None
        self.discriminator = None

        if basic_info is not None:
            self.basic_info = basic_info
        if charge_detail is not None:
            self.charge_detail = charge_detail
        if endpoints is not None:
            self.endpoints = endpoints
        if nodes is not None:
            self.nodes = nodes

    @property
    def basic_info(self):
        """Gets the basic_info of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The basic_info of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: BasicInfoForDescribeDBInstanceDetailOutput
        """
        return self._basic_info

    @basic_info.setter
    def basic_info(self, basic_info):
        """Sets the basic_info of this DescribeDBInstanceDetailResponse.


        :param basic_info: The basic_info of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: BasicInfoForDescribeDBInstanceDetailOutput
        """

        self._basic_info = basic_info

    @property
    def charge_detail(self):
        """Gets the charge_detail of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The charge_detail of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: ChargeDetailForDescribeDBInstanceDetailOutput
        """
        return self._charge_detail

    @charge_detail.setter
    def charge_detail(self, charge_detail):
        """Sets the charge_detail of this DescribeDBInstanceDetailResponse.


        :param charge_detail: The charge_detail of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: ChargeDetailForDescribeDBInstanceDetailOutput
        """

        self._charge_detail = charge_detail

    @property
    def endpoints(self):
        """Gets the endpoints of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The endpoints of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: list[EndpointForDescribeDBInstanceDetailOutput]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """Sets the endpoints of this DescribeDBInstanceDetailResponse.


        :param endpoints: The endpoints of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: list[EndpointForDescribeDBInstanceDetailOutput]
        """

        self._endpoints = endpoints

    @property
    def nodes(self):
        """Gets the nodes of this DescribeDBInstanceDetailResponse.  # noqa: E501


        :return: The nodes of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :rtype: list[NodeForDescribeDBInstanceDetailOutput]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """Sets the nodes of this DescribeDBInstanceDetailResponse.


        :param nodes: The nodes of this DescribeDBInstanceDetailResponse.  # noqa: E501
        :type: list[NodeForDescribeDBInstanceDetailOutput]
        """

        self._nodes = nodes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDBInstanceDetailResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDBInstanceDetailResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDBInstanceDetailResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

import datetime
import hmac
import hashlib
from six.moves.urllib.parse import quote


class SignerV4(object):

    @staticmethod
    def sign(path, method, headers, body, query, ak, sk, region, service):
        if path == '':
            path = '/'
        if method != 'GET' and not ('Content-Type' in headers):
            headers['Content-Type'] = 'application/x-www-form-urlencoded; charset=utf-8'
        format_date = datetime.datetime.utcnow().strftime("%Y%m%dT%H%M%SZ")
        headers['X-Date'] = format_date

        body_hash = hashlib.sha256(body.encode('utf-8')).hexdigest()
        headers['X-Content-Sha256'] = body_hash

        signed_headers = dict()
        for key in headers:
            if key in ['Content-Type', 'Content-Md5', 'Host'] or key.startswith('X-'):
                signed_headers[key.lower()] = headers[key]

        if 'host' in signed_headers:
            v = signed_headers['host']
            if v.find(':') != -1:
                split = v.split(':')
                port = split[1]
                if str(port) == '80' or str(port) == '443':
                    signed_headers['host'] = split[0]

        signed_str = ''
        for key in sorted(signed_headers.keys()):
            signed_str += key + ':' + signed_headers[key] + '\n'

        signed_headers_string = ';'.join(sorted(signed_headers.keys()))

        canonical_request = '\n'.join(
            [method, path, SignerV4.canonical_query(dict(query)), signed_str, signed_headers_string, body_hash])
        credential_scope = '/'.join([format_date[:8], region, service, 'request'])
        signing_str = '\n'.join(['HMAC-SHA256', format_date, credential_scope,
                                 hashlib.sha256(canonical_request.encode('utf-8')).hexdigest()])
        signing_key = SignerV4.get_signing_secret_key_v4(sk, format_date[:8], region, service)

        signature = hmac.new(signing_key, signing_str.encode('utf-8'), hashlib.sha256).hexdigest()

        credential = ak + '/' + credential_scope
        headers[
            'Authorization'] = 'HMAC-SHA256' + ' Credential=' + credential + ', SignedHeaders=' + \
                               signed_headers_string + ', Signature=' + signature
        return

    @staticmethod
    def canonical_query(query):
        res = []
        for key in query:
            value = str(query[key])
            res.append((quote(key, safe='-_.~'), quote(value, safe='-_.~')))
        sorted_key_vals = []
        for key, value in sorted(res):
            sorted_key_vals.append('%s=%s' % (key, value))
        return '&'.join(sorted_key_vals)

    @staticmethod
    def get_signing_secret_key_v4(sk, date, region, service):
        kdate = SignerV4.hmac_sha256(sk.encode('utf-8'), date)
        kregion = SignerV4.hmac_sha256(kdate, region)
        kservice = SignerV4.hmac_sha256(kregion, service)
        return SignerV4.hmac_sha256(kservice, 'request')

    @staticmethod
    def hmac_sha256(key, msg):
        return hmac.new(key, msg.encode('utf-8'), hashlib.sha256).digest()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DataForListDatabasesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_names': 'str',
        'character_set_name': 'str',
        'db_name': 'str',
        'db_status': 'str'
    }

    attribute_map = {
        'account_names': 'AccountNames',
        'character_set_name': 'CharacterSetName',
        'db_name': 'DBName',
        'db_status': 'DBStatus'
    }

    def __init__(self, account_names=None, character_set_name=None, db_name=None, db_status=None, _configuration=None):  # noqa: E501
        """DataForListDatabasesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_names = None
        self._character_set_name = None
        self._db_name = None
        self._db_status = None
        self.discriminator = None

        if account_names is not None:
            self.account_names = account_names
        if character_set_name is not None:
            self.character_set_name = character_set_name
        if db_name is not None:
            self.db_name = db_name
        if db_status is not None:
            self.db_status = db_status

    @property
    def account_names(self):
        """Gets the account_names of this DataForListDatabasesOutput.  # noqa: E501


        :return: The account_names of this DataForListDatabasesOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_names

    @account_names.setter
    def account_names(self, account_names):
        """Sets the account_names of this DataForListDatabasesOutput.


        :param account_names: The account_names of this DataForListDatabasesOutput.  # noqa: E501
        :type: str
        """

        self._account_names = account_names

    @property
    def character_set_name(self):
        """Gets the character_set_name of this DataForListDatabasesOutput.  # noqa: E501


        :return: The character_set_name of this DataForListDatabasesOutput.  # noqa: E501
        :rtype: str
        """
        return self._character_set_name

    @character_set_name.setter
    def character_set_name(self, character_set_name):
        """Sets the character_set_name of this DataForListDatabasesOutput.


        :param character_set_name: The character_set_name of this DataForListDatabasesOutput.  # noqa: E501
        :type: str
        """

        self._character_set_name = character_set_name

    @property
    def db_name(self):
        """Gets the db_name of this DataForListDatabasesOutput.  # noqa: E501


        :return: The db_name of this DataForListDatabasesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this DataForListDatabasesOutput.


        :param db_name: The db_name of this DataForListDatabasesOutput.  # noqa: E501
        :type: str
        """

        self._db_name = db_name

    @property
    def db_status(self):
        """Gets the db_status of this DataForListDatabasesOutput.  # noqa: E501


        :return: The db_status of this DataForListDatabasesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_status

    @db_status.setter
    def db_status(self, db_status):
        """Sets the db_status of this DataForListDatabasesOutput.


        :param db_status: The db_status of this DataForListDatabasesOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["Running"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_status not in allowed_values):
            raise ValueError(
                "Invalid value for `db_status` ({0}), must be one of {1}"  # noqa: E501
                .format(db_status, allowed_values)
            )

        self._db_status = db_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataForListDatabasesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataForListDatabasesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataForListDatabasesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ParameterForDescribeApplyParameterTemplateOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'new_value': 'str',
        'old_value': 'str',
        'restart': 'bool',
        'result': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'new_value': 'NewValue',
        'old_value': 'OldValue',
        'restart': 'Restart',
        'result': 'Result'
    }

    def __init__(self, name=None, new_value=None, old_value=None, restart=None, result=None, _configuration=None):  # noqa: E501
        """ParameterForDescribeApplyParameterTemplateOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._new_value = None
        self._old_value = None
        self._restart = None
        self._result = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if new_value is not None:
            self.new_value = new_value
        if old_value is not None:
            self.old_value = old_value
        if restart is not None:
            self.restart = restart
        if result is not None:
            self.result = result

    @property
    def name(self):
        """Gets the name of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501


        :return: The name of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ParameterForDescribeApplyParameterTemplateOutput.


        :param name: The name of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def new_value(self):
        """Gets the new_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501


        :return: The new_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """Sets the new_value of this ParameterForDescribeApplyParameterTemplateOutput.


        :param new_value: The new_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :type: str
        """

        self._new_value = new_value

    @property
    def old_value(self):
        """Gets the old_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501


        :return: The old_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._old_value

    @old_value.setter
    def old_value(self, old_value):
        """Sets the old_value of this ParameterForDescribeApplyParameterTemplateOutput.


        :param old_value: The old_value of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :type: str
        """

        self._old_value = old_value

    @property
    def restart(self):
        """Gets the restart of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501


        :return: The restart of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :rtype: bool
        """
        return self._restart

    @restart.setter
    def restart(self, restart):
        """Sets the restart of this ParameterForDescribeApplyParameterTemplateOutput.


        :param restart: The restart of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :type: bool
        """

        self._restart = restart

    @property
    def result(self):
        """Gets the result of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501


        :return: The result of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this ParameterForDescribeApplyParameterTemplateOutput.


        :param result: The result of this ParameterForDescribeApplyParameterTemplateOutput.  # noqa: E501
        :type: str
        """

        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParameterForDescribeApplyParameterTemplateOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParameterForDescribeApplyParameterTemplateOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParameterForDescribeApplyParameterTemplateOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class FilterForListNodePoolsInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_scaling_enabled': 'bool',
        'cluster_ids': 'list[str]',
        'create_client_token': 'str',
        'ids': 'list[str]',
        'name': 'str',
        'statuses': 'list[StatusForListNodePoolsInput]',
        'update_client_token': 'str'
    }

    attribute_map = {
        'auto_scaling_enabled': 'AutoScaling.Enabled',
        'cluster_ids': 'ClusterIds',
        'create_client_token': 'CreateClientToken',
        'ids': 'Ids',
        'name': 'Name',
        'statuses': 'Statuses',
        'update_client_token': 'UpdateClientToken'
    }

    def __init__(self, auto_scaling_enabled=None, cluster_ids=None, create_client_token=None, ids=None, name=None, statuses=None, update_client_token=None, _configuration=None):  # noqa: E501
        """FilterForListNodePoolsInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_scaling_enabled = None
        self._cluster_ids = None
        self._create_client_token = None
        self._ids = None
        self._name = None
        self._statuses = None
        self._update_client_token = None
        self.discriminator = None

        if auto_scaling_enabled is not None:
            self.auto_scaling_enabled = auto_scaling_enabled
        if cluster_ids is not None:
            self.cluster_ids = cluster_ids
        if create_client_token is not None:
            self.create_client_token = create_client_token
        if ids is not None:
            self.ids = ids
        if name is not None:
            self.name = name
        if statuses is not None:
            self.statuses = statuses
        if update_client_token is not None:
            self.update_client_token = update_client_token

    @property
    def auto_scaling_enabled(self):
        """Gets the auto_scaling_enabled of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The auto_scaling_enabled of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: bool
        """
        return self._auto_scaling_enabled

    @auto_scaling_enabled.setter
    def auto_scaling_enabled(self, auto_scaling_enabled):
        """Sets the auto_scaling_enabled of this FilterForListNodePoolsInput.


        :param auto_scaling_enabled: The auto_scaling_enabled of this FilterForListNodePoolsInput.  # noqa: E501
        :type: bool
        """

        self._auto_scaling_enabled = auto_scaling_enabled

    @property
    def cluster_ids(self):
        """Gets the cluster_ids of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The cluster_ids of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._cluster_ids

    @cluster_ids.setter
    def cluster_ids(self, cluster_ids):
        """Sets the cluster_ids of this FilterForListNodePoolsInput.


        :param cluster_ids: The cluster_ids of this FilterForListNodePoolsInput.  # noqa: E501
        :type: list[str]
        """

        self._cluster_ids = cluster_ids

    @property
    def create_client_token(self):
        """Gets the create_client_token of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The create_client_token of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: str
        """
        return self._create_client_token

    @create_client_token.setter
    def create_client_token(self, create_client_token):
        """Sets the create_client_token of this FilterForListNodePoolsInput.


        :param create_client_token: The create_client_token of this FilterForListNodePoolsInput.  # noqa: E501
        :type: str
        """

        self._create_client_token = create_client_token

    @property
    def ids(self):
        """Gets the ids of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The ids of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this FilterForListNodePoolsInput.


        :param ids: The ids of this FilterForListNodePoolsInput.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    @property
    def name(self):
        """Gets the name of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The name of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FilterForListNodePoolsInput.


        :param name: The name of this FilterForListNodePoolsInput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def statuses(self):
        """Gets the statuses of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The statuses of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: list[StatusForListNodePoolsInput]
        """
        return self._statuses

    @statuses.setter
    def statuses(self, statuses):
        """Sets the statuses of this FilterForListNodePoolsInput.


        :param statuses: The statuses of this FilterForListNodePoolsInput.  # noqa: E501
        :type: list[StatusForListNodePoolsInput]
        """

        self._statuses = statuses

    @property
    def update_client_token(self):
        """Gets the update_client_token of this FilterForListNodePoolsInput.  # noqa: E501


        :return: The update_client_token of this FilterForListNodePoolsInput.  # noqa: E501
        :rtype: str
        """
        return self._update_client_token

    @update_client_token.setter
    def update_client_token(self, update_client_token):
        """Sets the update_client_token of this FilterForListNodePoolsInput.


        :param update_client_token: The update_client_token of this FilterForListNodePoolsInput.  # noqa: E501
        :type: str
        """

        self._update_client_token = update_client_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FilterForListNodePoolsInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FilterForListNodePoolsInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FilterForListNodePoolsInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class AlarmPolicyConditionForModifyScalingPolicyInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comparison_operator': 'str',
        'metric_name': 'str',
        'metric_unit': 'str',
        'threshold': 'str'
    }

    attribute_map = {
        'comparison_operator': 'ComparisonOperator',
        'metric_name': 'MetricName',
        'metric_unit': 'MetricUnit',
        'threshold': 'Threshold'
    }

    def __init__(self, comparison_operator=None, metric_name=None, metric_unit=None, threshold=None, _configuration=None):  # noqa: E501
        """AlarmPolicyConditionForModifyScalingPolicyInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._comparison_operator = None
        self._metric_name = None
        self._metric_unit = None
        self._threshold = None
        self.discriminator = None

        if comparison_operator is not None:
            self.comparison_operator = comparison_operator
        if metric_name is not None:
            self.metric_name = metric_name
        if metric_unit is not None:
            self.metric_unit = metric_unit
        if threshold is not None:
            self.threshold = threshold

    @property
    def comparison_operator(self):
        """Gets the comparison_operator of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501


        :return: The comparison_operator of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :rtype: str
        """
        return self._comparison_operator

    @comparison_operator.setter
    def comparison_operator(self, comparison_operator):
        """Sets the comparison_operator of this AlarmPolicyConditionForModifyScalingPolicyInput.


        :param comparison_operator: The comparison_operator of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :type: str
        """

        self._comparison_operator = comparison_operator

    @property
    def metric_name(self):
        """Gets the metric_name of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501


        :return: The metric_name of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """Sets the metric_name of this AlarmPolicyConditionForModifyScalingPolicyInput.


        :param metric_name: The metric_name of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :type: str
        """

        self._metric_name = metric_name

    @property
    def metric_unit(self):
        """Gets the metric_unit of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501


        :return: The metric_unit of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :rtype: str
        """
        return self._metric_unit

    @metric_unit.setter
    def metric_unit(self, metric_unit):
        """Sets the metric_unit of this AlarmPolicyConditionForModifyScalingPolicyInput.


        :param metric_unit: The metric_unit of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :type: str
        """

        self._metric_unit = metric_unit

    @property
    def threshold(self):
        """Gets the threshold of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501


        :return: The threshold of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :rtype: str
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this AlarmPolicyConditionForModifyScalingPolicyInput.


        :param threshold: The threshold of this AlarmPolicyConditionForModifyScalingPolicyInput.  # noqa: E501
        :type: str
        """

        self._threshold = threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlarmPolicyConditionForModifyScalingPolicyInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmPolicyConditionForModifyScalingPolicyInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AlarmPolicyConditionForModifyScalingPolicyInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ScheduledPolicyForDescribeScalingPoliciesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'launch_time': 'str',
        'recurrence_end_time': 'str',
        'recurrence_start_time': 'str',
        'recurrence_type': 'str',
        'recurrence_value': 'str'
    }

    attribute_map = {
        'launch_time': 'LaunchTime',
        'recurrence_end_time': 'RecurrenceEndTime',
        'recurrence_start_time': 'RecurrenceStartTime',
        'recurrence_type': 'RecurrenceType',
        'recurrence_value': 'RecurrenceValue'
    }

    def __init__(self, launch_time=None, recurrence_end_time=None, recurrence_start_time=None, recurrence_type=None, recurrence_value=None, _configuration=None):  # noqa: E501
        """ScheduledPolicyForDescribeScalingPoliciesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._launch_time = None
        self._recurrence_end_time = None
        self._recurrence_start_time = None
        self._recurrence_type = None
        self._recurrence_value = None
        self.discriminator = None

        if launch_time is not None:
            self.launch_time = launch_time
        if recurrence_end_time is not None:
            self.recurrence_end_time = recurrence_end_time
        if recurrence_start_time is not None:
            self.recurrence_start_time = recurrence_start_time
        if recurrence_type is not None:
            self.recurrence_type = recurrence_type
        if recurrence_value is not None:
            self.recurrence_value = recurrence_value

    @property
    def launch_time(self):
        """Gets the launch_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The launch_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._launch_time

    @launch_time.setter
    def launch_time(self, launch_time):
        """Sets the launch_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.


        :param launch_time: The launch_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._launch_time = launch_time

    @property
    def recurrence_end_time(self):
        """Gets the recurrence_end_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The recurrence_end_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._recurrence_end_time

    @recurrence_end_time.setter
    def recurrence_end_time(self, recurrence_end_time):
        """Sets the recurrence_end_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.


        :param recurrence_end_time: The recurrence_end_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._recurrence_end_time = recurrence_end_time

    @property
    def recurrence_start_time(self):
        """Gets the recurrence_start_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The recurrence_start_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._recurrence_start_time

    @recurrence_start_time.setter
    def recurrence_start_time(self, recurrence_start_time):
        """Sets the recurrence_start_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.


        :param recurrence_start_time: The recurrence_start_time of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._recurrence_start_time = recurrence_start_time

    @property
    def recurrence_type(self):
        """Gets the recurrence_type of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The recurrence_type of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._recurrence_type

    @recurrence_type.setter
    def recurrence_type(self, recurrence_type):
        """Sets the recurrence_type of this ScheduledPolicyForDescribeScalingPoliciesOutput.


        :param recurrence_type: The recurrence_type of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._recurrence_type = recurrence_type

    @property
    def recurrence_value(self):
        """Gets the recurrence_value of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The recurrence_value of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._recurrence_value

    @recurrence_value.setter
    def recurrence_value(self, recurrence_value):
        """Sets the recurrence_value of this ScheduledPolicyForDescribeScalingPoliciesOutput.


        :param recurrence_value: The recurrence_value of this ScheduledPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._recurrence_value = recurrence_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScheduledPolicyForDescribeScalingPoliciesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduledPolicyForDescribeScalingPoliciesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScheduledPolicyForDescribeScalingPoliciesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ScalingGroupForDescribeScalingGroupsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_scaling_configuration_id': 'str',
        'created_at': 'str',
        'db_instance_ids': 'list[str]',
        'default_cooldown': 'int',
        'desire_instance_number': 'int',
        'instance_terminate_policy': 'str',
        'lifecycle_state': 'str',
        'max_instance_number': 'int',
        'min_instance_number': 'int',
        'multi_az_policy': 'str',
        'scaling_group_id': 'str',
        'scaling_group_name': 'str',
        'server_group_attributes': 'list[ServerGroupAttributeForDescribeScalingGroupsOutput]',
        'subnet_ids': 'list[str]',
        'total_instance_count': 'int',
        'updated_at': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'active_scaling_configuration_id': 'ActiveScalingConfigurationId',
        'created_at': 'CreatedAt',
        'db_instance_ids': 'DBInstanceIds',
        'default_cooldown': 'DefaultCooldown',
        'desire_instance_number': 'DesireInstanceNumber',
        'instance_terminate_policy': 'InstanceTerminatePolicy',
        'lifecycle_state': 'LifecycleState',
        'max_instance_number': 'MaxInstanceNumber',
        'min_instance_number': 'MinInstanceNumber',
        'multi_az_policy': 'MultiAZPolicy',
        'scaling_group_id': 'ScalingGroupId',
        'scaling_group_name': 'ScalingGroupName',
        'server_group_attributes': 'ServerGroupAttributes',
        'subnet_ids': 'SubnetIds',
        'total_instance_count': 'TotalInstanceCount',
        'updated_at': 'UpdatedAt',
        'vpc_id': 'VpcId'
    }

    def __init__(self, active_scaling_configuration_id=None, created_at=None, db_instance_ids=None, default_cooldown=None, desire_instance_number=None, instance_terminate_policy=None, lifecycle_state=None, max_instance_number=None, min_instance_number=None, multi_az_policy=None, scaling_group_id=None, scaling_group_name=None, server_group_attributes=None, subnet_ids=None, total_instance_count=None, updated_at=None, vpc_id=None, _configuration=None):  # noqa: E501
        """ScalingGroupForDescribeScalingGroupsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_scaling_configuration_id = None
        self._created_at = None
        self._db_instance_ids = None
        self._default_cooldown = None
        self._desire_instance_number = None
        self._instance_terminate_policy = None
        self._lifecycle_state = None
        self._max_instance_number = None
        self._min_instance_number = None
        self._multi_az_policy = None
        self._scaling_group_id = None
        self._scaling_group_name = None
        self._server_group_attributes = None
        self._subnet_ids = None
        self._total_instance_count = None
        self._updated_at = None
        self._vpc_id = None
        self.discriminator = None

        if active_scaling_configuration_id is not None:
            self.active_scaling_configuration_id = active_scaling_configuration_id
        if created_at is not None:
            self.created_at = created_at
        if db_instance_ids is not None:
            self.db_instance_ids = db_instance_ids
        if default_cooldown is not None:
            self.default_cooldown = default_cooldown
        if desire_instance_number is not None:
            self.desire_instance_number = desire_instance_number
        if instance_terminate_policy is not None:
            self.instance_terminate_policy = instance_terminate_policy
        if lifecycle_state is not None:
            self.lifecycle_state = lifecycle_state
        if max_instance_number is not None:
            self.max_instance_number = max_instance_number
        if min_instance_number is not None:
            self.min_instance_number = min_instance_number
        if multi_az_policy is not None:
            self.multi_az_policy = multi_az_policy
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id
        if scaling_group_name is not None:
            self.scaling_group_name = scaling_group_name
        if server_group_attributes is not None:
            self.server_group_attributes = server_group_attributes
        if subnet_ids is not None:
            self.subnet_ids = subnet_ids
        if total_instance_count is not None:
            self.total_instance_count = total_instance_count
        if updated_at is not None:
            self.updated_at = updated_at
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def active_scaling_configuration_id(self):
        """Gets the active_scaling_configuration_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The active_scaling_configuration_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._active_scaling_configuration_id

    @active_scaling_configuration_id.setter
    def active_scaling_configuration_id(self, active_scaling_configuration_id):
        """Sets the active_scaling_configuration_id of this ScalingGroupForDescribeScalingGroupsOutput.


        :param active_scaling_configuration_id: The active_scaling_configuration_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._active_scaling_configuration_id = active_scaling_configuration_id

    @property
    def created_at(self):
        """Gets the created_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The created_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ScalingGroupForDescribeScalingGroupsOutput.


        :param created_at: The created_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def db_instance_ids(self):
        """Gets the db_instance_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The db_instance_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._db_instance_ids

    @db_instance_ids.setter
    def db_instance_ids(self, db_instance_ids):
        """Sets the db_instance_ids of this ScalingGroupForDescribeScalingGroupsOutput.


        :param db_instance_ids: The db_instance_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: list[str]
        """

        self._db_instance_ids = db_instance_ids

    @property
    def default_cooldown(self):
        """Gets the default_cooldown of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The default_cooldown of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._default_cooldown

    @default_cooldown.setter
    def default_cooldown(self, default_cooldown):
        """Sets the default_cooldown of this ScalingGroupForDescribeScalingGroupsOutput.


        :param default_cooldown: The default_cooldown of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: int
        """

        self._default_cooldown = default_cooldown

    @property
    def desire_instance_number(self):
        """Gets the desire_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The desire_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._desire_instance_number

    @desire_instance_number.setter
    def desire_instance_number(self, desire_instance_number):
        """Sets the desire_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.


        :param desire_instance_number: The desire_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: int
        """

        self._desire_instance_number = desire_instance_number

    @property
    def instance_terminate_policy(self):
        """Gets the instance_terminate_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The instance_terminate_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_terminate_policy

    @instance_terminate_policy.setter
    def instance_terminate_policy(self, instance_terminate_policy):
        """Sets the instance_terminate_policy of this ScalingGroupForDescribeScalingGroupsOutput.


        :param instance_terminate_policy: The instance_terminate_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._instance_terminate_policy = instance_terminate_policy

    @property
    def lifecycle_state(self):
        """Gets the lifecycle_state of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The lifecycle_state of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """Sets the lifecycle_state of this ScalingGroupForDescribeScalingGroupsOutput.


        :param lifecycle_state: The lifecycle_state of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._lifecycle_state = lifecycle_state

    @property
    def max_instance_number(self):
        """Gets the max_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The max_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._max_instance_number

    @max_instance_number.setter
    def max_instance_number(self, max_instance_number):
        """Sets the max_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.


        :param max_instance_number: The max_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: int
        """

        self._max_instance_number = max_instance_number

    @property
    def min_instance_number(self):
        """Gets the min_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The min_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._min_instance_number

    @min_instance_number.setter
    def min_instance_number(self, min_instance_number):
        """Sets the min_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.


        :param min_instance_number: The min_instance_number of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: int
        """

        self._min_instance_number = min_instance_number

    @property
    def multi_az_policy(self):
        """Gets the multi_az_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The multi_az_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._multi_az_policy

    @multi_az_policy.setter
    def multi_az_policy(self, multi_az_policy):
        """Sets the multi_az_policy of this ScalingGroupForDescribeScalingGroupsOutput.


        :param multi_az_policy: The multi_az_policy of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._multi_az_policy = multi_az_policy

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The scaling_group_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ScalingGroupForDescribeScalingGroupsOutput.


        :param scaling_group_id: The scaling_group_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    @property
    def scaling_group_name(self):
        """Gets the scaling_group_name of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The scaling_group_name of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_name

    @scaling_group_name.setter
    def scaling_group_name(self, scaling_group_name):
        """Sets the scaling_group_name of this ScalingGroupForDescribeScalingGroupsOutput.


        :param scaling_group_name: The scaling_group_name of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._scaling_group_name = scaling_group_name

    @property
    def server_group_attributes(self):
        """Gets the server_group_attributes of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The server_group_attributes of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: list[ServerGroupAttributeForDescribeScalingGroupsOutput]
        """
        return self._server_group_attributes

    @server_group_attributes.setter
    def server_group_attributes(self, server_group_attributes):
        """Sets the server_group_attributes of this ScalingGroupForDescribeScalingGroupsOutput.


        :param server_group_attributes: The server_group_attributes of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: list[ServerGroupAttributeForDescribeScalingGroupsOutput]
        """

        self._server_group_attributes = server_group_attributes

    @property
    def subnet_ids(self):
        """Gets the subnet_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The subnet_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """Sets the subnet_ids of this ScalingGroupForDescribeScalingGroupsOutput.


        :param subnet_ids: The subnet_ids of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: list[str]
        """

        self._subnet_ids = subnet_ids

    @property
    def total_instance_count(self):
        """Gets the total_instance_count of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The total_instance_count of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._total_instance_count

    @total_instance_count.setter
    def total_instance_count(self, total_instance_count):
        """Sets the total_instance_count of this ScalingGroupForDescribeScalingGroupsOutput.


        :param total_instance_count: The total_instance_count of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: int
        """

        self._total_instance_count = total_instance_count

    @property
    def updated_at(self):
        """Gets the updated_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The updated_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ScalingGroupForDescribeScalingGroupsOutput.


        :param updated_at: The updated_at of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def vpc_id(self):
        """Gets the vpc_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501


        :return: The vpc_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this ScalingGroupForDescribeScalingGroupsOutput.


        :param vpc_id: The vpc_id of this ScalingGroupForDescribeScalingGroupsOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScalingGroupForDescribeScalingGroupsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScalingGroupForDescribeScalingGroupsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScalingGroupForDescribeScalingGroupsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateLifecycleHookRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lifecycle_hook_name': 'str',
        'lifecycle_hook_policy': 'str',
        'lifecycle_hook_timeout': 'int',
        'lifecycle_hook_type': 'str',
        'scaling_group_id': 'str'
    }

    attribute_map = {
        'lifecycle_hook_name': 'LifecycleHookName',
        'lifecycle_hook_policy': 'LifecycleHookPolicy',
        'lifecycle_hook_timeout': 'LifecycleHookTimeout',
        'lifecycle_hook_type': 'LifecycleHookType',
        'scaling_group_id': 'ScalingGroupId'
    }

    def __init__(self, lifecycle_hook_name=None, lifecycle_hook_policy=None, lifecycle_hook_timeout=None, lifecycle_hook_type=None, scaling_group_id=None, _configuration=None):  # noqa: E501
        """CreateLifecycleHookRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._lifecycle_hook_name = None
        self._lifecycle_hook_policy = None
        self._lifecycle_hook_timeout = None
        self._lifecycle_hook_type = None
        self._scaling_group_id = None
        self.discriminator = None

        if lifecycle_hook_name is not None:
            self.lifecycle_hook_name = lifecycle_hook_name
        if lifecycle_hook_policy is not None:
            self.lifecycle_hook_policy = lifecycle_hook_policy
        if lifecycle_hook_timeout is not None:
            self.lifecycle_hook_timeout = lifecycle_hook_timeout
        if lifecycle_hook_type is not None:
            self.lifecycle_hook_type = lifecycle_hook_type
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id

    @property
    def lifecycle_hook_name(self):
        """Gets the lifecycle_hook_name of this CreateLifecycleHookRequest.  # noqa: E501


        :return: The lifecycle_hook_name of this CreateLifecycleHookRequest.  # noqa: E501
        :rtype: str
        """
        return self._lifecycle_hook_name

    @lifecycle_hook_name.setter
    def lifecycle_hook_name(self, lifecycle_hook_name):
        """Sets the lifecycle_hook_name of this CreateLifecycleHookRequest.


        :param lifecycle_hook_name: The lifecycle_hook_name of this CreateLifecycleHookRequest.  # noqa: E501
        :type: str
        """

        self._lifecycle_hook_name = lifecycle_hook_name

    @property
    def lifecycle_hook_policy(self):
        """Gets the lifecycle_hook_policy of this CreateLifecycleHookRequest.  # noqa: E501


        :return: The lifecycle_hook_policy of this CreateLifecycleHookRequest.  # noqa: E501
        :rtype: str
        """
        return self._lifecycle_hook_policy

    @lifecycle_hook_policy.setter
    def lifecycle_hook_policy(self, lifecycle_hook_policy):
        """Sets the lifecycle_hook_policy of this CreateLifecycleHookRequest.


        :param lifecycle_hook_policy: The lifecycle_hook_policy of this CreateLifecycleHookRequest.  # noqa: E501
        :type: str
        """

        self._lifecycle_hook_policy = lifecycle_hook_policy

    @property
    def lifecycle_hook_timeout(self):
        """Gets the lifecycle_hook_timeout of this CreateLifecycleHookRequest.  # noqa: E501


        :return: The lifecycle_hook_timeout of this CreateLifecycleHookRequest.  # noqa: E501
        :rtype: int
        """
        return self._lifecycle_hook_timeout

    @lifecycle_hook_timeout.setter
    def lifecycle_hook_timeout(self, lifecycle_hook_timeout):
        """Sets the lifecycle_hook_timeout of this CreateLifecycleHookRequest.


        :param lifecycle_hook_timeout: The lifecycle_hook_timeout of this CreateLifecycleHookRequest.  # noqa: E501
        :type: int
        """

        self._lifecycle_hook_timeout = lifecycle_hook_timeout

    @property
    def lifecycle_hook_type(self):
        """Gets the lifecycle_hook_type of this CreateLifecycleHookRequest.  # noqa: E501


        :return: The lifecycle_hook_type of this CreateLifecycleHookRequest.  # noqa: E501
        :rtype: str
        """
        return self._lifecycle_hook_type

    @lifecycle_hook_type.setter
    def lifecycle_hook_type(self, lifecycle_hook_type):
        """Sets the lifecycle_hook_type of this CreateLifecycleHookRequest.


        :param lifecycle_hook_type: The lifecycle_hook_type of this CreateLifecycleHookRequest.  # noqa: E501
        :type: str
        """

        self._lifecycle_hook_type = lifecycle_hook_type

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this CreateLifecycleHookRequest.  # noqa: E501


        :return: The scaling_group_id of this CreateLifecycleHookRequest.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this CreateLifecycleHookRequest.


        :param scaling_group_id: The scaling_group_id of this CreateLifecycleHookRequest.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateLifecycleHookRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLifecycleHookRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateLifecycleHookRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import print_function
import volcenginesdkautoscaling
import volcenginesdkcore
from pprint import pprint
from volcenginesdkcore.rest import ApiException

if __name__ == '__main__':
    configuration = volcenginesdkcore.Configuration()
    configuration.ak = "AK"
    configuration.sk = "SK"
    configuration.region = "cn-beijing"

    try:
        api_instance = volcenginesdkautoscaling.AUTOSCALINGApi(volcenginesdkcore.ApiClient(configuration))
        resp = api_instance.describe_scaling_groups(volcenginesdkautoscaling.DescribeScalingGroupsRequest(

        ))
        pprint(resp)
    except ApiException as e:
        print("Exception when calling AUTOSCALINGApi->describe_scaling_groups: %s\n" % e)



# coding: utf-8

"""
    cr

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ItemForListTagsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chart_attribute': 'ChartAttributeForListTagsOutput',
        'digest': 'str',
        'image_attributes': 'list[ImageAttributeForListTagsOutput]',
        'name': 'str',
        'push_time': 'str',
        'size': 'int',
        'type': 'str'
    }

    attribute_map = {
        'chart_attribute': 'ChartAttribute',
        'digest': 'Digest',
        'image_attributes': 'ImageAttributes',
        'name': 'Name',
        'push_time': 'PushTime',
        'size': 'Size',
        'type': 'Type'
    }

    def __init__(self, chart_attribute=None, digest=None, image_attributes=None, name=None, push_time=None, size=None, type=None, _configuration=None):  # noqa: E501
        """ItemForListTagsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._chart_attribute = None
        self._digest = None
        self._image_attributes = None
        self._name = None
        self._push_time = None
        self._size = None
        self._type = None
        self.discriminator = None

        if chart_attribute is not None:
            self.chart_attribute = chart_attribute
        if digest is not None:
            self.digest = digest
        if image_attributes is not None:
            self.image_attributes = image_attributes
        if name is not None:
            self.name = name
        if push_time is not None:
            self.push_time = push_time
        if size is not None:
            self.size = size
        if type is not None:
            self.type = type

    @property
    def chart_attribute(self):
        """Gets the chart_attribute of this ItemForListTagsOutput.  # noqa: E501


        :return: The chart_attribute of this ItemForListTagsOutput.  # noqa: E501
        :rtype: ChartAttributeForListTagsOutput
        """
        return self._chart_attribute

    @chart_attribute.setter
    def chart_attribute(self, chart_attribute):
        """Sets the chart_attribute of this ItemForListTagsOutput.


        :param chart_attribute: The chart_attribute of this ItemForListTagsOutput.  # noqa: E501
        :type: ChartAttributeForListTagsOutput
        """

        self._chart_attribute = chart_attribute

    @property
    def digest(self):
        """Gets the digest of this ItemForListTagsOutput.  # noqa: E501


        :return: The digest of this ItemForListTagsOutput.  # noqa: E501
        :rtype: str
        """
        return self._digest

    @digest.setter
    def digest(self, digest):
        """Sets the digest of this ItemForListTagsOutput.


        :param digest: The digest of this ItemForListTagsOutput.  # noqa: E501
        :type: str
        """

        self._digest = digest

    @property
    def image_attributes(self):
        """Gets the image_attributes of this ItemForListTagsOutput.  # noqa: E501


        :return: The image_attributes of this ItemForListTagsOutput.  # noqa: E501
        :rtype: list[ImageAttributeForListTagsOutput]
        """
        return self._image_attributes

    @image_attributes.setter
    def image_attributes(self, image_attributes):
        """Sets the image_attributes of this ItemForListTagsOutput.


        :param image_attributes: The image_attributes of this ItemForListTagsOutput.  # noqa: E501
        :type: list[ImageAttributeForListTagsOutput]
        """

        self._image_attributes = image_attributes

    @property
    def name(self):
        """Gets the name of this ItemForListTagsOutput.  # noqa: E501


        :return: The name of this ItemForListTagsOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ItemForListTagsOutput.


        :param name: The name of this ItemForListTagsOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def push_time(self):
        """Gets the push_time of this ItemForListTagsOutput.  # noqa: E501


        :return: The push_time of this ItemForListTagsOutput.  # noqa: E501
        :rtype: str
        """
        return self._push_time

    @push_time.setter
    def push_time(self, push_time):
        """Sets the push_time of this ItemForListTagsOutput.


        :param push_time: The push_time of this ItemForListTagsOutput.  # noqa: E501
        :type: str
        """

        self._push_time = push_time

    @property
    def size(self):
        """Gets the size of this ItemForListTagsOutput.  # noqa: E501


        :return: The size of this ItemForListTagsOutput.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ItemForListTagsOutput.


        :param size: The size of this ItemForListTagsOutput.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def type(self):
        """Gets the type of this ItemForListTagsOutput.  # noqa: E501


        :return: The type of this ItemForListTagsOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ItemForListTagsOutput.


        :param type: The type of this ItemForListTagsOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemForListTagsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemForListTagsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemForListTagsOutput):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import volcenginesdkcore
import volcenginesdkvke

from helper import VKEOption, create_vke


if __name__ == "__main__":

    # 设置VKE服务的选项
    # ``your_``开头的字段需要替换
    cluster_name = "your_cluster_name"
    network_mode = "your_cluster_network_mode"  # 选项: Flannel, VpcCniShared
    subnet_ids = "your_subnet_id"  # 类型: list
    # 如果是Flannel网络模式的集群，需要填写``pod_cidrs``
    pod_cidrs = "your_pod_cidr"  # 类型: list
    service_cidrs = "your_service_cidr"  # 类型: list
    node_pool_name = "your_node_pool_name"
    instance_type = "your_instance_type"
    password = "your_password"

    # 这里以创建一个Flannel网络模式的集群为例
    vke_opt = VKEOption(
        cluster_name=cluster_name,
        network_mode=network_mode,
        node_pool_name=node_pool_name,
        instance_type=instance_type,
        password=password,
        subnet_ids=subnet_ids,
        service_cidrs=service_cidrs,
        pod_cidrs=pod_cidrs,
    )

    # 设置火山配置
    # ``your_``开头的字段需要替换
    configuration = volcenginesdkcore.Configuration()
    configuration.ak = "your_ak"
    configuration.sk = "your_sk"
    configuration.region = "your_region"

    # 创建VKEApi实例
    api_instance = volcenginesdkvke.VKEApi(volcenginesdkcore.ApiClient(configuration))

    # 创建VKE服务
    create_vke(api_instance, vke_opt)



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class BasicInfoForDescribeDBInstanceOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'charge_status': 'str',
        'charge_type': 'str',
        'create_time': 'str',
        'db_engine': 'str',
        'db_engine_version': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_spec': 'InstanceSpecForDescribeDBInstanceOutput',
        'instance_status': 'str',
        'instance_type': 'str',
        'read_only_instance_ids': 'list[str]',
        'region': 'str',
        'storage_space_gb': 'int',
        'update_time': 'str',
        'vpc_id': 'str',
        'zone': 'str'
    }

    attribute_map = {
        'charge_status': 'ChargeStatus',
        'charge_type': 'ChargeType',
        'create_time': 'CreateTime',
        'db_engine': 'DBEngine',
        'db_engine_version': 'DBEngineVersion',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_spec': 'InstanceSpec',
        'instance_status': 'InstanceStatus',
        'instance_type': 'InstanceType',
        'read_only_instance_ids': 'ReadOnlyInstanceIds',
        'region': 'Region',
        'storage_space_gb': 'StorageSpaceGB',
        'update_time': 'UpdateTime',
        'vpc_id': 'VpcID',
        'zone': 'Zone'
    }

    def __init__(self, charge_status=None, charge_type=None, create_time=None, db_engine=None, db_engine_version=None, instance_id=None, instance_name=None, instance_spec=None, instance_status=None, instance_type=None, read_only_instance_ids=None, region=None, storage_space_gb=None, update_time=None, vpc_id=None, zone=None, _configuration=None):  # noqa: E501
        """BasicInfoForDescribeDBInstanceOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._charge_status = None
        self._charge_type = None
        self._create_time = None
        self._db_engine = None
        self._db_engine_version = None
        self._instance_id = None
        self._instance_name = None
        self._instance_spec = None
        self._instance_status = None
        self._instance_type = None
        self._read_only_instance_ids = None
        self._region = None
        self._storage_space_gb = None
        self._update_time = None
        self._vpc_id = None
        self._zone = None
        self.discriminator = None

        if charge_status is not None:
            self.charge_status = charge_status
        if charge_type is not None:
            self.charge_type = charge_type
        if create_time is not None:
            self.create_time = create_time
        if db_engine is not None:
            self.db_engine = db_engine
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_spec is not None:
            self.instance_spec = instance_spec
        if instance_status is not None:
            self.instance_status = instance_status
        if instance_type is not None:
            self.instance_type = instance_type
        if read_only_instance_ids is not None:
            self.read_only_instance_ids = read_only_instance_ids
        if region is not None:
            self.region = region
        if storage_space_gb is not None:
            self.storage_space_gb = storage_space_gb
        if update_time is not None:
            self.update_time = update_time
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone is not None:
            self.zone = zone

    @property
    def charge_status(self):
        """Gets the charge_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The charge_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_status

    @charge_status.setter
    def charge_status(self, charge_status):
        """Sets the charge_status of this BasicInfoForDescribeDBInstanceOutput.


        :param charge_status: The charge_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Overdue", "Unpaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                charge_status not in allowed_values):
            raise ValueError(
                "Invalid value for `charge_status` ({0}), must be one of {1}"  # noqa: E501
                .format(charge_status, allowed_values)
            )

        self._charge_status = charge_status

    @property
    def charge_type(self):
        """Gets the charge_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The charge_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this BasicInfoForDescribeDBInstanceOutput.


        :param charge_type: The charge_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["NotEnabled", "PostPaid", "Prepaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                charge_type not in allowed_values):
            raise ValueError(
                "Invalid value for `charge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(charge_type, allowed_values)
            )

        self._charge_type = charge_type

    @property
    def create_time(self):
        """Gets the create_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The create_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this BasicInfoForDescribeDBInstanceOutput.


        :param create_time: The create_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def db_engine(self):
        """Gets the db_engine of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The db_engine of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine

    @db_engine.setter
    def db_engine(self, db_engine):
        """Sets the db_engine of this BasicInfoForDescribeDBInstanceOutput.


        :param db_engine: The db_engine of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine, allowed_values)
            )

        self._db_engine = db_engine

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The db_engine_version of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this BasicInfoForDescribeDBInstanceOutput.


        :param db_engine_version: The db_engine_version of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL_8_0", "MySQL_Community_5_7"]  # noqa: E501
        if (self._configuration.client_side_validation and
                db_engine_version not in allowed_values):
            raise ValueError(
                "Invalid value for `db_engine_version` ({0}), must be one of {1}"  # noqa: E501
                .format(db_engine_version, allowed_values)
            )

        self._db_engine_version = db_engine_version

    @property
    def instance_id(self):
        """Gets the instance_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The instance_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this BasicInfoForDescribeDBInstanceOutput.


        :param instance_id: The instance_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The instance_name of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this BasicInfoForDescribeDBInstanceOutput.


        :param instance_name: The instance_name of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_spec(self):
        """Gets the instance_spec of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The instance_spec of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: InstanceSpecForDescribeDBInstanceOutput
        """
        return self._instance_spec

    @instance_spec.setter
    def instance_spec(self, instance_spec):
        """Sets the instance_spec of this BasicInfoForDescribeDBInstanceOutput.


        :param instance_spec: The instance_spec of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: InstanceSpecForDescribeDBInstanceOutput
        """

        self._instance_spec = instance_spec

    @property
    def instance_status(self):
        """Gets the instance_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The instance_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this BasicInfoForDescribeDBInstanceOutput.


        :param instance_status: The instance_status of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["AllowListMaintaining", "Closed", "Closing", "CreateFailed", "Creating", "Deleting", "Destroyed", "Destroying", "Error", "Importing", "Maintaining", "MasterChanging", "Migrating", "Reclaiming", "Recycled", "Released", "Restarting", "Restoring", "Resuming", "Running", "SSLUpdating", "TDEUpdating", "Unknown", "Updating", "Upgrading", "WaitingPaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_status not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_status` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_status, allowed_values)
            )

        self._instance_status = instance_status

    @property
    def instance_type(self):
        """Gets the instance_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The instance_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this BasicInfoForDescribeDBInstanceOutput.


        :param instance_type: The instance_type of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """
        allowed_values = ["HA"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_type, allowed_values)
            )

        self._instance_type = instance_type

    @property
    def read_only_instance_ids(self):
        """Gets the read_only_instance_ids of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The read_only_instance_ids of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._read_only_instance_ids

    @read_only_instance_ids.setter
    def read_only_instance_ids(self, read_only_instance_ids):
        """Sets the read_only_instance_ids of this BasicInfoForDescribeDBInstanceOutput.


        :param read_only_instance_ids: The read_only_instance_ids of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: list[str]
        """

        self._read_only_instance_ids = read_only_instance_ids

    @property
    def region(self):
        """Gets the region of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The region of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this BasicInfoForDescribeDBInstanceOutput.


        :param region: The region of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def storage_space_gb(self):
        """Gets the storage_space_gb of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The storage_space_gb of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: int
        """
        return self._storage_space_gb

    @storage_space_gb.setter
    def storage_space_gb(self, storage_space_gb):
        """Sets the storage_space_gb of this BasicInfoForDescribeDBInstanceOutput.


        :param storage_space_gb: The storage_space_gb of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: int
        """

        self._storage_space_gb = storage_space_gb

    @property
    def update_time(self):
        """Gets the update_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The update_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this BasicInfoForDescribeDBInstanceOutput.


        :param update_time: The update_time of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The vpc_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this BasicInfoForDescribeDBInstanceOutput.


        :param vpc_id: The vpc_id of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone(self):
        """Gets the zone of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501


        :return: The zone of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this BasicInfoForDescribeDBInstanceOutput.


        :param zone: The zone of this BasicInfoForDescribeDBInstanceOutput.  # noqa: E501
        :type: str
        """

        self._zone = zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BasicInfoForDescribeDBInstanceOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BasicInfoForDescribeDBInstanceOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BasicInfoForDescribeDBInstanceOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
# Borrowed from https://github.com/amirziai/flatten

# python 2 and python 3 compatibility library
import six


class Flatten(object):

    def __init__(self, nested_dict, separator=".", start_index=1, root_keys_to_ignore=None, replace_separators=None):
        """
        :param nested_dict: dictionary we want to flatten
        :param start_index: start index for list param
        :param separator: string to separate dictionary keys by
        :param root_keys_to_ignore: set of root keys to ignore from flattening
        :param str replace_separators: Replace separators within keys
        """
        self.nested_dict = nested_dict
        self.separator = separator
        self.start_index = start_index
        self.root_keys_to_ignore = root_keys_to_ignore
        self.replace_separators = replace_separators

    def flat(self):
        if not isinstance(self.nested_dict, dict):
            raise TypeError("flatten requires a dictionary input")

        if not isinstance(self.separator, six.string_types):
            raise TypeError("separator must be string")

        if self.root_keys_to_ignore is None:
            root_keys_to_ignore = set()

        if len(self.nested_dict) == 0:
            return {}

        # This global dictionary stores the flattened keys and values and is
        # ultimately returned
        flattened_dict = dict()

        def _flatten(object_, key):
            """
            For dict, list and set objects_ calls itself on the elements and for
            other types assigns the object_ to
            the corresponding key in the global flattened_dict
            :param object_: object to flatten
            :param key: carries the concatenated key for the object_
            :return: None
            """
            # Empty object can't be iterated, take as is
            if not object_:
                flattened_dict[key] = object_
            # These object types support iteration
            elif isinstance(object_, dict):
                for object_key in object_:
                    if not (not key and object_key in root_keys_to_ignore):
                        _flatten(
                            object_[object_key],
                            self._construct_key(
                                key,
                                self.separator,
                                object_key,
                                replace_separators=self.replace_separators))
            elif isinstance(object_, (list, set, tuple)):
                for index, item in enumerate(object_):
                    _flatten(
                        item,
                        self._construct_key(
                            key,
                            self.separator,
                            index + self.start_index,
                            replace_separators=self.replace_separators))
            # Anything left take as is
            else:
                flattened_dict[key] = object_

        _flatten(self.nested_dict, None)
        return flattened_dict

    def _construct_key(self, previous_key, separator, new_key, replace_separators=None):
        """
        Returns the new_key if no previous key exists, otherwise concatenates
        previous key, separator, and new_key
        :param previous_key:
        :param separator:
        :param new_key:
        :param str replace_separators: Replace separators within keys
        :return: a string if previous_key exists and simply passes through the
        new_key otherwise
        """
        if replace_separators is not None:
            new_key = str(new_key).replace(separator, replace_separators)
        if previous_key:
            return u"{}{}{}".format(previous_key, separator, new_key)
        else:
            return new_key



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateParameterTemplateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'template_desc': 'str',
        'template_name': 'str',
        'template_params': 'list[TemplateParamForCreateParameterTemplateInput]',
        'template_type': 'str',
        'template_type_version': 'str'
    }

    attribute_map = {
        'template_desc': 'TemplateDesc',
        'template_name': 'TemplateName',
        'template_params': 'TemplateParams',
        'template_type': 'TemplateType',
        'template_type_version': 'TemplateTypeVersion'
    }

    def __init__(self, template_desc=None, template_name=None, template_params=None, template_type=None, template_type_version=None, _configuration=None):  # noqa: E501
        """CreateParameterTemplateRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._template_desc = None
        self._template_name = None
        self._template_params = None
        self._template_type = None
        self._template_type_version = None
        self.discriminator = None

        if template_desc is not None:
            self.template_desc = template_desc
        if template_name is not None:
            self.template_name = template_name
        if template_params is not None:
            self.template_params = template_params
        if template_type is not None:
            self.template_type = template_type
        if template_type_version is not None:
            self.template_type_version = template_type_version

    @property
    def template_desc(self):
        """Gets the template_desc of this CreateParameterTemplateRequest.  # noqa: E501


        :return: The template_desc of this CreateParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_desc

    @template_desc.setter
    def template_desc(self, template_desc):
        """Sets the template_desc of this CreateParameterTemplateRequest.


        :param template_desc: The template_desc of this CreateParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                template_desc is not None and len(template_desc) > 200):
            raise ValueError("Invalid value for `template_desc`, length must be less than or equal to `200`")  # noqa: E501

        self._template_desc = template_desc

    @property
    def template_name(self):
        """Gets the template_name of this CreateParameterTemplateRequest.  # noqa: E501


        :return: The template_name of this CreateParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this CreateParameterTemplateRequest.


        :param template_name: The template_name of this CreateParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                template_name is not None and len(template_name) > 64):
            raise ValueError("Invalid value for `template_name`, length must be less than or equal to `64`")  # noqa: E501
        if (self._configuration.client_side_validation and
                template_name is not None and len(template_name) < 2):
            raise ValueError("Invalid value for `template_name`, length must be greater than or equal to `2`")  # noqa: E501

        self._template_name = template_name

    @property
    def template_params(self):
        """Gets the template_params of this CreateParameterTemplateRequest.  # noqa: E501


        :return: The template_params of this CreateParameterTemplateRequest.  # noqa: E501
        :rtype: list[TemplateParamForCreateParameterTemplateInput]
        """
        return self._template_params

    @template_params.setter
    def template_params(self, template_params):
        """Sets the template_params of this CreateParameterTemplateRequest.


        :param template_params: The template_params of this CreateParameterTemplateRequest.  # noqa: E501
        :type: list[TemplateParamForCreateParameterTemplateInput]
        """

        self._template_params = template_params

    @property
    def template_type(self):
        """Gets the template_type of this CreateParameterTemplateRequest.  # noqa: E501


        :return: The template_type of this CreateParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this CreateParameterTemplateRequest.


        :param template_type: The template_type of this CreateParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type, allowed_values)
            )

        self._template_type = template_type

    @property
    def template_type_version(self):
        """Gets the template_type_version of this CreateParameterTemplateRequest.  # noqa: E501


        :return: The template_type_version of this CreateParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_type_version

    @template_type_version.setter
    def template_type_version(self, template_type_version):
        """Sets the template_type_version of this CreateParameterTemplateRequest.


        :param template_type_version: The template_type_version of this CreateParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["MySQL_8_0", "MySQL_Community_5_7"]  # noqa: E501
        if (self._configuration.client_side_validation and
                template_type_version not in allowed_values):
            raise ValueError(
                "Invalid value for `template_type_version` ({0}), must be one of {1}"  # noqa: E501
                .format(template_type_version, allowed_values)
            )

        self._template_type_version = template_type_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateParameterTemplateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateParameterTemplateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateParameterTemplateRequest):
            return True

        return self.to_dict() != other.to_dict()
